================
 Document Title
================
----------
 Subtitle
----------

Section Title
=============
* a bullet point using "*"

  - a sub-list using "-"

    + yet another sub-list

  - another item

